import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_1p2zy","start":"checkbox__start_1p2zy","center":"checkbox__center_1p2zy","addons":"checkbox__addons_1p2zy","block":"checkbox__block_1p2zy","box":"checkbox__box_1p2zy","checkedIcon":"checkbox__checkedIcon_1p2zy","s":"checkbox__s_1p2zy","disabled":"checkbox__disabled_1p2zy","inactive":"checkbox__inactive_1p2zy","checked":"checkbox__checked_1p2zy","indeterminate":"checkbox__indeterminate_1p2zy","label":"checkbox__label_1p2zy","hint":"checkbox__hint_1p2zy","focused":"checkbox__focused_1p2zy","content":"checkbox__content_1p2zy","errorMessage":"checkbox__errorMessage_1p2zy","indeterminateLine":"checkbox__indeterminateLine_1p2zy"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, error, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.inactive]: inactive,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId }, restProps)),
        React.createElement("span", { className: styles.box },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
